@@ -1,8 +1,7 @@
 # Copyright: Ankitects Pty Ltd and contributors
 # License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
 
-"""Helpers for serializing third-party collections to a common JSON form.
-"""
+"""Helpers for serializing third-party collections to a common JSON form."""
 
 from __future__ import annotations
 
