@@ -27,6 +27,7 @@ from aqt.operations import QueryOp
 from aqt.progress import ProgressUpdate
 from aqt.qt import *
 from aqt.utils import (
+    add_close_shortcut,
     checkInvalidFilename,
     disable_help_button,
     getSaveFile,
@@ -53,6 +54,7 @@ class ExportDialog(QDialog):
         self.nids = nids
         disable_help_button(self)
         self.setup(did)
+        add_close_shortcut(self)
         self.open()
 
     def setup(self, did: DeckId | None) -> None:
