@@ -177,9 +177,13 @@ class CustomStyles:
     QPushButton:default {{
         border: 1px solid {tm.var(colors.BORDER_FOCUS)};
     }}
-    QPushButton:focus {{
+    QPushButton {{
+        margin: 1px;
+    }}
+    QPushButton:focus, QPushButton:default:hover {{
         border: 2px solid {tm.var(colors.BORDER_FOCUS)};
         outline: none;
+        margin: 0px;
     }}
     QPushButton:hover,
     QTabBar::tab:hover,
@@ -195,9 +199,6 @@ class CustomStyles:
             )
         };
     }}
-    QPushButton:default:hover {{
-        border-width: 2px;
-    }}
     QPushButton:pressed,
     QPushButton:checked,
     QSpinBox::up-button:pressed,
